pub enum NumericPerNoteExpression {
PitchBend,
Timbre,
Aftertouch,
}Expand description
Numeric expression controllers that affect a single note of the synth.
Variants
PitchBend
Pitch bend note expression.
This corresponds to the NumericGlobalExpression::PitchBend controller and should
change the tuning of the note.
This is expressed in semitones away from the root note of the note (which may itself be tuned).
Timbre
Vertical movement note expression, meant to control some sort of timbre of the synth.
This is called “slide” in some DAW UIs.
This corresponds to the NumericGlobalExpression::Timbre controller, and
its effects must be combined with the global controller.
This value varies from 0->1, 0 being the bottommost position, and 1 being the topmost position.
Aftertouch
Depthwise note expression.
This is called “Pressure” in some DAW UIs.
This value varies from 0->1, 0 being neutral, and 1 being the maximum depth.
This corresponds to the NumericGlobalExpression::Aftertouch controller which
affects all notes. The total effect must be a combination of this per-note note
expression and the global controller.