SynthParamStates

Trait SynthParamStates 

pub trait SynthParamStates: States {
    // Required methods
    fn get_numeric_global_expression(
        &self,
        expression: NumericGlobalExpression,
    ) -> f32;
    fn get_switch_global_expression(
        &self,
        expression: SwitchGlobalExpression,
    ) -> bool;
    fn get_numeric_expression_for_note(
        &self,
        expression: NumericPerNoteExpression,
        note_id: NoteID,
    ) -> f32;
}
Extention to the parameters::States trait for synths.

Required Methods

fn get_numeric_global_expression( &self, expression: NumericGlobalExpression, ) -> f32

Get the current value of a numeric global expression controller.

fn get_switch_global_expression( &self, expression: SwitchGlobalExpression, ) -> bool

Get the current value of a switch global expression controller.

fn get_numeric_expression_for_note( &self, expression: NumericPerNoteExpression, note_id: NoteID, ) -> f32

Get the current value of a numeric per-note expression controller.

Implementors