pub enum NumericGlobalExpression {
PitchBend,
ModWheel,
ExpressionPedal,
Aftertouch,
Timbre,
}Expand description
Numeric expression controllers that affect all playing notes of the synth.
Variants
PitchBend
The global pitch bend.
This ranges from -1.0 to 1.0, and represents the current state of the pitch bend controller. How to interpret this value in semitones precisely is up to each synth.
Note that there is also a per-note pitch bend expression parameter, this should be combined with the global pitch bend to get the total amount of bend for each note.
ModWheel
The mod wheel.
This ranges from 0.0 to 1.0, and represents the current state of the mod wheel.
ExpressionPedal
The expression pedal.
This ranges from 0.0 to 1.0, and represents the current state of the expression pedal.
Aftertouch
Aftertouch, or “pressure” in some DAW UIs.
This ranges from 0.0 to 1.0, and represents the current state of the global aftertouch.
Note that there is also a per-note aftertouch expression parameter, this should be combined with the global aftertouch to get the total amount of aftertouch for each note.
Timbre
Timbre, or “slide” in some DAW UIs.
This ranges from 0.0 to 1.0, and represents the current state of the global timbre control.
Note that there is also a per-note timbre expression parameter, this should be combined with the global timbre to get the total amount of timbre for each note.