pub trait SynthParamBufferStates: BufferStates {
// Required methods
fn get_numeric_global_expression(
&self,
expression: NumericGlobalExpression,
) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>;
fn get_switch_global_expression(
&self,
expression: SwitchGlobalExpression,
) -> SwitchBufferState<impl Iterator<Item = TimedValue<bool>> + Clone>;
fn get_numeric_expression_for_note(
&self,
expression: NumericPerNoteExpression,
note_id: NoteID,
) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>;
}Expand description
Extension to the parameters::BufferStates trait for synths.
Required Methods
Sourcefn get_numeric_global_expression(
&self,
expression: NumericGlobalExpression,
) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>
fn get_numeric_global_expression( &self, expression: NumericGlobalExpression, ) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>
Get the current value of a numeric global expression controller.
Sourcefn get_switch_global_expression(
&self,
expression: SwitchGlobalExpression,
) -> SwitchBufferState<impl Iterator<Item = TimedValue<bool>> + Clone>
fn get_switch_global_expression( &self, expression: SwitchGlobalExpression, ) -> SwitchBufferState<impl Iterator<Item = TimedValue<bool>> + Clone>
Get the current value of a switch global expression controller.
Sourcefn get_numeric_expression_for_note(
&self,
expression: NumericPerNoteExpression,
note_id: NoteID,
) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>
fn get_numeric_expression_for_note( &self, expression: NumericPerNoteExpression, note_id: NoteID, ) -> NumericBufferState<impl Iterator<Item = PiecewiseLinearCurvePoint> + Clone>
Get the current value of a numeric per-note expression controller.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.